==> owncloud-4.0.4.tgz: owncloud/apps/calendar/l10n/ar.php <==
<?php $TRANSLATIONS = array(
"Wrong calendar" => "جدول زمني خاطئ",
"New Timezone:" => "التوقيت الجديد",
"Timezone changed" => "تم تغيير المنطقة الزمنية",
"Invalid request" => "طلب غير مفهوم",
"Calendar" => "الجدول الزمني",
"Birthday" => "عيد ميلاد",
"Business" => "عمل",
"Call" => "إتصال",
"Clients" => "الزبائن",
"Deliverer" => "المرسل",
"Holidays" => "عطلة",
"Ideas" => "أفكار",
"Journey" => "رحلة",
"Jubilee" => "يوبيل",
"Meeting" => "إجتماع",
"Other" => "شيء آخر",
"Personal" => "شخصي",
"Projects" => "مشاريع",
"Questions" => "اسئلة",
"Work" => "العمل",
"Does not repeat" => "لا يعاد",
"Daily" => "يومي",
"Weekly" => "أسبوعي",
"Every Weekday" => "كل نهاية الأسبوع",
"Bi-Weekly" => "كل اسبوعين",
"Monthly" => "شهري",
"Yearly" => "سنوي",
"never" => "بتاتا",
"by occurrences" => "حسب تسلسل الحدوث",
"by date" => "حسب التاريخ",
"by monthday" => "حسب يوم الشهر",
"by weekday" => "حسب يوم الاسبوع",
"Monday" => "الأثنين",
"Tuesday" => "الثلاثاء",
"Wednesday" => "الاربعاء",
"Thursday" => "الخميس",
"Friday" => "الجمعه",
"Saturday" => "السبت",
"Sunday" => "الاحد",
"events week of month" => "الاحداث باسبوع الشهر",
"first" => "أول",
"second" => "ثاني",
"third" => "ثالث",
"fourth" => "رابع",
"fifth" => "خامس",
"last" => "أخير",
"January" => "كانون الثاني",
"February" => "شباط",
"March" => "آذار",
"April" => "نيسان",
"May" => "أيار",
"June" => "حزيران",
"July" => "تموز",
"August" => "آب",
"September" => "أيلول",
"October" => "تشرين الاول",
"November" => "تشرين الثاني",
"December" => "كانون الاول",
"by events date" => "حسب تاريخ الحدث",
"by yearday(s)" => "حسب يوم السنه",
"by weeknumber(s)" => "حسب رقم الاسبوع",
"by day and month" => "حسب اليوم و الشهر",
"Date" => "تاريخ",
"Cal." => "تقويم",
"All day" => "كل النهار",
"New Calendar" => "جدول زمني جديد",
"Missing fields" => "خانات خالية من المعلومات",
"Title" => "عنوان",
"From Date" => "من تاريخ",
"From Time" => "إلى تاريخ",
"To Date" => "إلى يوم",
"To Time" => "إلى وقت",
"The event ends before it starts" => "هذا الحدث ينتهي قبل أن يبدأ",
"There was a database fail" => "خطأ في قاعدة البيانات",
"Week" => "إسبوع",
"Month" => "شهر",
"List" => "قائمة",
"Today" => "اليوم",
"Calendars" => "الجداول الزمنية",
"There was a fail, while parsing the file." => "لم يتم قراءة الملف بنجاح.",
"Choose active calendars" => "إختر الجدول الزمني الرئيسي",
"CalDav Link" => "وصلة CalDav",
"Download" => "تحميل",
"Edit" => "تعديل",
"Delete" => "حذف",
"New calendar" => "جدول زمني جديد",
"Edit calendar" => "عادل الجدول الزمني",
"Displayname" => "الاسم المرئي",
"Active" => "حالي",
"Calendar color" => "لون الجدول الزمني",
"Save" => "إحفظ",
"Submit" => "أرسل",
"Cancel" => "إلغاء",
"Edit an event" => "عادل حدث",
"Export" => "تصدير المعلومات",
"Title of the Event" => "عنوان الحدث",
"Category" => "فئة",
"All Day Event" => "حدث في يوم كامل",
"From" => "من",
"To" => "إلى",
"Advanced options" => "خيارات متقدمة",
"Location" => "مكان",
"Location of the Event" => "مكان الحدث",
"Description" => "مواصفات",
"Description of the Event" => "وصف الحدث",
"Repeat" => "إعادة",
"Advanced" => "تعديلات متقدمه",
"Select weekdays" => "اختر ايام الاسبوع",
"Select days" => "اختر الايام",
"and the events day of year." => "و التواريخ حسب يوم السنه.",
"and the events day of month." => "و الاحداث حسب يوم الشهر.",
"Select months" => "اختر الاشهر",
"Select weeks" => "اختر الاسابيع",
"and the events week of year." => "و الاحداث حسب اسبوع السنه",
"Interval" => "المده الفاصله",
"End" => "نهايه",
"occurrences" => "الاحداث",
"Import a calendar file" => "أدخل ملف التقويم",
"Please choose the calendar" => "الرجاء إختر الجدول الزمني",
"create a new calendar" => "انشاء جدول زمني جديد",
"Name of new calendar" => "أسم الجدول الزمني الجديد",
"Import" => "إدخال",
"Importing calendar" => "يتم ادخال الجدول الزمني",
"Calendar imported successfully" => "تم ادخال الجدول الزمني بنجاح",
"Close Dialog" => "أغلق الحوار",
"Create a new event" => "إضافة حدث جديد",
"Select category" => "اختر الفئة",
"Timezone" => "المنطقة الزمنية",
"Check always for changes of the timezone" => "راقب دائما تغير التقويم الزمني",
"Timeformat" => "شكل الوقت",
"24h" => "24 ساعة",
"12h" => "12 ساعة",
"Calendar CalDAV syncing address:" => "عنوان لتحديث ال CalDAV الجدول الزمني"
);

==> owncloud-4.5.7.tgz: owncloud/apps/calendar/l10n/ar.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "ليس جميع الجداول الزمنيه محفوضه مؤقة",
"Everything seems to be completely cached" => "كل شيء محفوض مؤقة",
"No calendars found." => "لم يتم العثور على جدول الزمني",
"No events found." => "لم يتم العثور على احداث",
"Wrong calendar" => "جدول زمني خاطئ",
"New Timezone:" => "التوقيت الجديد",
"Timezone changed" => "تم تغيير المنطقة الزمنية",
"Invalid request" => "طلب غير مفهوم",
"Calendar" => "الجدول الزمني",
"Editable" => "يمكن تعديله",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "ddd M/d",
"MMMM yyyy" => "ddd M/d",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Birthday" => "عيد ميلاد",
"Business" => "عمل",
"Call" => "إتصال",
"Clients" => "الزبائن",
"Deliverer" => "المرسل",
"Holidays" => "عطلة",
"Ideas" => "أفكار",
"Journey" => "رحلة",
"Jubilee" => "يوبيل",
"Meeting" => "إجتماع",
"Other" => "شيء آخر",
"Personal" => "شخصي",
"Projects" => "مشاريع",
"Questions" => "اسئلة",
"Work" => "العمل",
"by" => "من قبل",
"unnamed" => "غير مسمى",
"New Calendar" => "جدول زمني جديد",
"Does not repeat" => "لا يعاد",
"Daily" => "يومي",
"Weekly" => "أسبوعي",
"Every Weekday" => "كل نهاية الأسبوع",
"Bi-Weekly" => "كل اسبوعين",
"Monthly" => "شهري",
"Yearly" => "سنوي",
"never" => "بتاتا",
"by occurrences" => "حسب تسلسل الحدوث",
"by date" => "حسب التاريخ",
"by monthday" => "حسب يوم الشهر",
"by weekday" => "حسب يوم الاسبوع",
"Monday" => "الأثنين",
"Tuesday" => "الثلاثاء",
"Wednesday" => "الاربعاء",
"Thursday" => "الخميس",
"Friday" => "الجمعه",
"Saturday" => "السبت",
"Sunday" => "الاحد",
"events week of month" => "الاحداث باسبوع الشهر",
"first" => "أول",
"second" => "ثاني",
"third" => "ثالث",
"fourth" => "رابع",
"fifth" => "خامس",
"last" => "أخير",
"January" => "كانون الثاني",
"February" => "شباط",
"March" => "آذار",
"April" => "نيسان",
"May" => "أيار",
"June" => "حزيران",
"July" => "تموز",
"August" => "آب",
"September" => "أيلول",
"October" => "تشرين الاول",
"November" => "تشرين الثاني",
"December" => "كانون الاول",
"by events date" => "حسب تاريخ الحدث",
"by yearday(s)" => "حسب يوم السنه",
"by weeknumber(s)" => "حسب رقم الاسبوع",
"by day and month" => "حسب اليوم و الشهر",
"Date" => "تاريخ",
"Cal." => "تقويم",
"Sun." => "أحد",
"Mon." => "أثن.",
"Tue." => "ثلا.",
"Wed." => "أرب.",
"Thu." => "خمي.",
"Fri." => "جمع.",
"Sat." => "سبت",
"Jan." => "ك2",
"Feb." => "شبا.",
"Mar." => "آذا.",
"Apr." => "نيس.",
"May." => "أيا.",
"All day" => "كل النهار",
"Missing fields" => "خانات خالية من المعلومات",
"Title" => "عنوان",
"From Date" => "من تاريخ",
"From Time" => "إلى تاريخ",
"To Date" => "إلى يوم",
"To Time" => "إلى وقت",
"The event ends before it starts" => "هذا الحدث ينتهي قبل أن يبدأ",
"There was a database fail" => "خطأ في قاعدة البيانات",
"Week" => "إسبوع",
"Month" => "شهر",
"List" => "قائمة",
"Today" => "اليوم",
"Your calendars" => "جداولك الزمنيه",
"CalDav Link" => "وصلة CalDav",
"Share Calendar" => "شارك الجدول الزمني",
"Download" => "تحميل",
"Edit" => "تعديل",
"Delete" => "حذف",
"shared with you by" => "مشاركه من قبل",
"New calendar" => "جدول زمني جديد",
"Edit calendar" => "عادل الجدول الزمني",
"Displayname" => "الاسم المرئي",
"Active" => "حالي",
"Calendar color" => "لون الجدول الزمني",
"Save" => "إحفظ",
"Submit" => "أرسل",
"Cancel" => "إلغاء",
"Edit an event" => "عادل حدث",
"Export" => "تصدير المعلومات",
"Eventinfo" => "تفاصيل الحدث",
"Repeating" => "يعاد",
"Alarm" => "تنبيه",
"Attendees" => "الحضور",
"Share" => "شارك",
"Title of the Event" => "عنوان الحدث",
"Category" => "فئة",
"Separate categories with commas" => "افصل الفئات بالفواصل",
"Edit categories" => "عدل الفئات",
"All Day Event" => "حدث في يوم كامل",
"From" => "من",
"To" => "إلى",
"Advanced options" => "خيارات متقدمة",
"Location" => "مكان",
"Location of the Event" => "مكان الحدث",
"Description" => "مواصفات",
"Description of the Event" => "وصف الحدث",
"Repeat" => "إعادة",
"Advanced" => "تعديلات متقدمه",
"Select weekdays" => "اختر ايام الاسبوع",
"Select days" => "اختر الايام",
"and the events day of year." => "و التواريخ حسب يوم السنه.",
"and the events day of month." => "و الاحداث حسب يوم الشهر.",
"Select months" => "اختر الاشهر",
"Select weeks" => "اختر الاسابيع",
"and the events week of year." => "و الاحداث حسب اسبوع السنه",
"Interval" => "المده الفاصله",
"End" => "نهايه",
"occurrences" => "الاحداث",
"create a new calendar" => "انشاء جدول زمني جديد",
"Import a calendar file" => "أدخل ملف التقويم",
"Name of new calendar" => "أسم الجدول الزمني الجديد",
"Import" => "إدخال",
"Close Dialog" => "أغلق الحوار",
"Create a new event" => "إضافة حدث جديد",
"View an event" => "شاهد الحدث",
"No categories selected" => "لم يتم اختيار الفئات",
"of" => "من",
"at" => "في",
"Timezone" => "المنطقة الزمنية",
"24h" => "24 ساعة",
"12h" => "12 ساعة"
);
